==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/devcenter/kotlin/ProjectEnvironmentTypeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devcenter.kotlin

import com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs.builder
import com.pulumi.azurenative.devcenter.kotlin.enums.EnvironmentTypeEnableStatus
import com.pulumi.azurenative.devcenter.kotlin.inputs.ManagedServiceIdentityArgs
import com.pulumi.azurenative.devcenter.kotlin.inputs.ManagedServiceIdentityArgsBuilder
import com.pulumi.azurenative.devcenter.kotlin.inputs.ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs
import com.pulumi.azurenative.devcenter.kotlin.inputs.ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgsBuilder
import com.pulumi.azurenative.devcenter.kotlin.inputs.UserRoleAssignmentArgs
import com.pulumi.azurenative.devcenter.kotlin.inputs.UserRoleAssignmentArgsBuilder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Represents an environment type.
 * Azure REST API version: 2023-04-01. Prior API version in Azure Native 1.x: 2022-09-01-preview.
 * Other available API versions: 2023-08-01-preview, 2023-10-01-preview.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:devcenter:ProjectEnvironmentType DevTest /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevCenter/projects/{projectName}/environmentTypes/{environmentTypeName}
 * ```
 * @property creatorRoleAssignment The role definition assigned to the environment creator on backing resources.
 * @property deploymentTargetId Id of a subscription that the environment type will be mapped to. The environment's resources will be deployed into this subscription.
 * @property environmentTypeName The name of the environment type.
 * @property identity Managed identity properties
 * @property location The geo-location for the environment type
 * @property projectName The name of the project.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property status Defines whether this Environment Type can be used in this Project.
 * @property tags Resource tags.
 * @property userRoleAssignments Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
 */
public data class ProjectEnvironmentTypeArgs(
    public val creatorRoleAssignment:
    Output<ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs>? = null,
    public val deploymentTargetId: Output<String>? = null,
    public val environmentTypeName: Output<String>? = null,
    public val identity: Output<ManagedServiceIdentityArgs>? = null,
    public val location: Output<String>? = null,
    public val projectName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val status: Output<Either<String, EnvironmentTypeEnableStatus>>? = null,
    public val tags: Output<Map<String, String>>? = null,
    public val userRoleAssignments: Output<Map<String, UserRoleAssignmentArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs> {
    override fun toJava(): com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs =
        com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs.builder()
            .creatorRoleAssignment(
                creatorRoleAssignment?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .deploymentTargetId(deploymentTargetId?.applyValue({ args0 -> args0 }))
            .environmentTypeName(environmentTypeName?.applyValue({ args0 -> args0 }))
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .location(location?.applyValue({ args0 -> args0 }))
            .projectName(projectName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .tags(tags?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .userRoleAssignments(
                userRoleAssignments?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.let({ args0 -> args0.toJava() }))
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ProjectEnvironmentTypeArgs].
 */
@PulumiTagMarker
public class ProjectEnvironmentTypeArgsBuilder internal constructor() {
    private var creatorRoleAssignment:
        Output<ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs>? = null

    private var deploymentTargetId: Output<String>? = null

    private var environmentTypeName: Output<String>? = null

    private var identity: Output<ManagedServiceIdentityArgs>? = null

    private var location: Output<String>? = null

    private var projectName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var status: Output<Either<String, EnvironmentTypeEnableStatus>>? = null

    private var tags: Output<Map<String, String>>? = null

    private var userRoleAssignments: Output<Map<String, UserRoleAssignmentArgs>>? = null

    /**
     * @param value The role definition assigned to the environment creator on backing resources.
     */
    @JvmName("wuxdilkyuqwhugfr")
    public suspend
    fun creatorRoleAssignment(`value`: Output<ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs>) {
        this.creatorRoleAssignment = value
    }

    /**
     * @param value Id of a subscription that the environment type will be mapped to. The environment's resources will be deployed into this subscription.
     */
    @JvmName("gwoivpjbfvnstbis")
    public suspend fun deploymentTargetId(`value`: Output<String>) {
        this.deploymentTargetId = value
    }

    /**
     * @param value The name of the environment type.
     */
    @JvmName("wgjkawjrxewuheql")
    public suspend fun environmentTypeName(`value`: Output<String>) {
        this.environmentTypeName = value
    }

    /**
     * @param value Managed identity properties
     */
    @JvmName("yeeondauxmxyfefn")
    public suspend fun identity(`value`: Output<ManagedServiceIdentityArgs>) {
        this.identity = value
    }

    /**
     * @param value The geo-location for the environment type
     */
    @JvmName("ggiqjcjkhbarbafw")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The name of the project.
     */
    @JvmName("kpuqvutijretmmas")
    public suspend fun projectName(`value`: Output<String>) {
        this.projectName = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("errbbybkhbpepbdb")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("wfrvpvahuqmddtfs")
    public suspend fun status(`value`: Output<Either<String, EnvironmentTypeEnableStatus>>) {
        this.status = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("cgojiyjkhkavospc")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("rmmmhcublhsrnsjt")
    public suspend fun userRoleAssignments(`value`: Output<Map<String, UserRoleAssignmentArgs>>) {
        this.userRoleAssignments = value
    }

    /**
     * @param value The role definition assigned to the environment creator on backing resources.
     */
    @JvmName("stdwpgthqilhgfkx")
    public suspend
    fun creatorRoleAssignment(`value`: ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.creatorRoleAssignment = mapped
    }

    /**
     * @param argument The role definition assigned to the environment creator on backing resources.
     */
    @JvmName("amfnqqmybcdsxdee")
    public suspend
    fun creatorRoleAssignment(argument: suspend ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgsBuilder.() -> Unit) {
        val toBeMapped =
            ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.creatorRoleAssignment = mapped
    }

    /**
     * @param value Id of a subscription that the environment type will be mapped to. The environment's resources will be deployed into this subscription.
     */
    @JvmName("wrlefhuvdnfpxpkj")
    public suspend fun deploymentTargetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentTargetId = mapped
    }

    /**
     * @param value The name of the environment type.
     */
    @JvmName("wxsmfckjcnmqrepp")
    public suspend fun environmentTypeName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environmentTypeName = mapped
    }

    /**
     * @param value Managed identity properties
     */
    @JvmName("vlmwvlgyopuaarvu")
    public suspend fun identity(`value`: ManagedServiceIdentityArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument Managed identity properties
     */
    @JvmName("nqsptrdmcgbnugcw")
    public suspend fun identity(argument: suspend ManagedServiceIdentityArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedServiceIdentityArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value The geo-location for the environment type
     */
    @JvmName("lbdontrtdhqclukq")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The name of the project.
     */
    @JvmName("sakfajmoneoplrra")
    public suspend fun projectName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.projectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("qilbihibadgvhcvn")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("hdsjwdfmreipaskn")
    public suspend fun status(`value`: Either<String, EnvironmentTypeEnableStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("benccwshxcchtvdv")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnvironmentTypeEnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("enrlafdbdmkyggrh")
    public fun status(`value`: EnvironmentTypeEnableStatus) {
        val toBeMapped = Either.ofRight<String, EnvironmentTypeEnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("mypipkblkvgwxkue")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("xtpqfvugsrlhqjse")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("kbvxyucohsuixfxs")
    public suspend fun userRoleAssignments(`value`: Map<String, UserRoleAssignmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userRoleAssignments = mapped
    }

    /**
     * @param argument Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("qfrcwpsanuecserr")
    public suspend fun userRoleAssignments(
        vararg
        argument: Pair<String, suspend UserRoleAssignmentArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                UserRoleAssignmentArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.userRoleAssignments = mapped
    }

    /**
     * @param values Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("pqpaaxsnvpeaxobs")
    public fun userRoleAssignments(vararg values: Pair<String, UserRoleAssignmentArgs>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userRoleAssignments = mapped
    }

    internal fun build(): ProjectEnvironmentTypeArgs = ProjectEnvironmentTypeArgs(
        creatorRoleAssignment = creatorRoleAssignment,
        deploymentTargetId = deploymentTargetId,
        environmentTypeName = environmentTypeName,
        identity = identity,
        location = location,
        projectName = projectName,
        resourceGroupName = resourceGroupName,
        status = status,
        tags = tags,
        userRoleAssignments = userRoleAssignments,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/devcenter/kotlin/ProjectEnvironmentTypeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devcenter.kotlin

import com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs.builder
import com.pulumi.azurenative.devcenter.kotlin.enums.EnvironmentTypeEnableStatus
import com.pulumi.azurenative.devcenter.kotlin.inputs.ManagedServiceIdentityArgs
import com.pulumi.azurenative.devcenter.kotlin.inputs.ManagedServiceIdentityArgsBuilder
import com.pulumi.azurenative.devcenter.kotlin.inputs.ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs
import com.pulumi.azurenative.devcenter.kotlin.inputs.ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgsBuilder
import com.pulumi.azurenative.devcenter.kotlin.inputs.UserRoleAssignmentArgs
import com.pulumi.azurenative.devcenter.kotlin.inputs.UserRoleAssignmentArgsBuilder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Represents an environment type.
 * Azure REST API version: 2023-04-01. Prior API version in Azure Native 1.x: 2022-09-01-preview.
 * Other available API versions: 2023-08-01-preview, 2023-10-01-preview, 2024-02-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:devcenter:ProjectEnvironmentType DevTest /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevCenter/projects/{projectName}/environmentTypes/{environmentTypeName}
 * ```
 * @property creatorRoleAssignment The role definition assigned to the environment creator on backing resources.
 * @property deploymentTargetId Id of a subscription that the environment type will be mapped to. The environment's resources will be deployed into this subscription.
 * @property environmentTypeName The name of the environment type.
 * @property identity Managed identity properties
 * @property location The geo-location for the environment type
 * @property projectName The name of the project.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property status Defines whether this Environment Type can be used in this Project.
 * @property tags Resource tags.
 * @property userRoleAssignments Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
 */
public data class ProjectEnvironmentTypeArgs(
    public val creatorRoleAssignment:
    Output<ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs>? = null,
    public val deploymentTargetId: Output<String>? = null,
    public val environmentTypeName: Output<String>? = null,
    public val identity: Output<ManagedServiceIdentityArgs>? = null,
    public val location: Output<String>? = null,
    public val projectName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val status: Output<Either<String, EnvironmentTypeEnableStatus>>? = null,
    public val tags: Output<Map<String, String>>? = null,
    public val userRoleAssignments: Output<Map<String, UserRoleAssignmentArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs> {
    override fun toJava(): com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs =
        com.pulumi.azurenative.devcenter.ProjectEnvironmentTypeArgs.builder()
            .creatorRoleAssignment(
                creatorRoleAssignment?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .deploymentTargetId(deploymentTargetId?.applyValue({ args0 -> args0 }))
            .environmentTypeName(environmentTypeName?.applyValue({ args0 -> args0 }))
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .location(location?.applyValue({ args0 -> args0 }))
            .projectName(projectName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .tags(tags?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .userRoleAssignments(
                userRoleAssignments?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.let({ args0 -> args0.toJava() }))
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ProjectEnvironmentTypeArgs].
 */
@PulumiTagMarker
public class ProjectEnvironmentTypeArgsBuilder internal constructor() {
    private var creatorRoleAssignment:
        Output<ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs>? = null

    private var deploymentTargetId: Output<String>? = null

    private var environmentTypeName: Output<String>? = null

    private var identity: Output<ManagedServiceIdentityArgs>? = null

    private var location: Output<String>? = null

    private var projectName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var status: Output<Either<String, EnvironmentTypeEnableStatus>>? = null

    private var tags: Output<Map<String, String>>? = null

    private var userRoleAssignments: Output<Map<String, UserRoleAssignmentArgs>>? = null

    /**
     * @param value The role definition assigned to the environment creator on backing resources.
     */
    @JvmName("uhgckbfyseomtsbr")
    public suspend
    fun creatorRoleAssignment(`value`: Output<ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs>) {
        this.creatorRoleAssignment = value
    }

    /**
     * @param value Id of a subscription that the environment type will be mapped to. The environment's resources will be deployed into this subscription.
     */
    @JvmName("cqydlsmepemapxqy")
    public suspend fun deploymentTargetId(`value`: Output<String>) {
        this.deploymentTargetId = value
    }

    /**
     * @param value The name of the environment type.
     */
    @JvmName("duwrrohktolsewxv")
    public suspend fun environmentTypeName(`value`: Output<String>) {
        this.environmentTypeName = value
    }

    /**
     * @param value Managed identity properties
     */
    @JvmName("vkgoexrxxyrrngca")
    public suspend fun identity(`value`: Output<ManagedServiceIdentityArgs>) {
        this.identity = value
    }

    /**
     * @param value The geo-location for the environment type
     */
    @JvmName("otntecnujsxffuhg")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The name of the project.
     */
    @JvmName("iusccqviexwadfxr")
    public suspend fun projectName(`value`: Output<String>) {
        this.projectName = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("hbnlwmnjdbeaxjcy")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("spsbnypnvsimrmqi")
    public suspend fun status(`value`: Output<Either<String, EnvironmentTypeEnableStatus>>) {
        this.status = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("mydxsbphccxajtmg")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("tjwevyybxarjnjlo")
    public suspend fun userRoleAssignments(`value`: Output<Map<String, UserRoleAssignmentArgs>>) {
        this.userRoleAssignments = value
    }

    /**
     * @param value The role definition assigned to the environment creator on backing resources.
     */
    @JvmName("ayqaiirswsddfwmj")
    public suspend
    fun creatorRoleAssignment(`value`: ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.creatorRoleAssignment = mapped
    }

    /**
     * @param argument The role definition assigned to the environment creator on backing resources.
     */
    @JvmName("uasunkrectnuqkvs")
    public suspend
    fun creatorRoleAssignment(argument: suspend ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgsBuilder.() -> Unit) {
        val toBeMapped =
            ProjectEnvironmentTypeUpdatePropertiesCreatorRoleAssignmentArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.creatorRoleAssignment = mapped
    }

    /**
     * @param value Id of a subscription that the environment type will be mapped to. The environment's resources will be deployed into this subscription.
     */
    @JvmName("babtdctqpqjohdyh")
    public suspend fun deploymentTargetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentTargetId = mapped
    }

    /**
     * @param value The name of the environment type.
     */
    @JvmName("nljubgvaegsfydpk")
    public suspend fun environmentTypeName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environmentTypeName = mapped
    }

    /**
     * @param value Managed identity properties
     */
    @JvmName("jupfhvjmkegdjdrh")
    public suspend fun identity(`value`: ManagedServiceIdentityArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument Managed identity properties
     */
    @JvmName("dmyxqytdisixhgwd")
    public suspend fun identity(argument: suspend ManagedServiceIdentityArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedServiceIdentityArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value The geo-location for the environment type
     */
    @JvmName("xjfimxqodyqjjonn")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The name of the project.
     */
    @JvmName("vrtnbepuonahpiaw")
    public suspend fun projectName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.projectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("aesvmcggucsoejws")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("yohlbnqhdlnlvxha")
    public suspend fun status(`value`: Either<String, EnvironmentTypeEnableStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("odcakjxgipmthknq")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnvironmentTypeEnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Defines whether this Environment Type can be used in this Project.
     */
    @JvmName("ritfhghnufxunwpc")
    public fun status(`value`: EnvironmentTypeEnableStatus) {
        val toBeMapped = Either.ofRight<String, EnvironmentTypeEnableStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("cvictuniukswvnly")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("tolapeaasyntgeme")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("jjsxfytvapwstycd")
    public suspend fun userRoleAssignments(`value`: Map<String, UserRoleAssignmentArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userRoleAssignments = mapped
    }

    /**
     * @param argument Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("bjekatqrwlssnfsv")
    public suspend fun userRoleAssignments(
        vararg
        argument: Pair<String, suspend UserRoleAssignmentArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                UserRoleAssignmentArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.userRoleAssignments = mapped
    }

    /**
     * @param values Role Assignments created on environment backing resources. This is a mapping from a user object ID to an object of role definition IDs.
     */
    @JvmName("vtmamrtxdnaxycei")
    public fun userRoleAssignments(vararg values: Pair<String, UserRoleAssignmentArgs>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userRoleAssignments = mapped
    }

    internal fun build(): ProjectEnvironmentTypeArgs = ProjectEnvironmentTypeArgs(
        creatorRoleAssignment = creatorRoleAssignment,
        deploymentTargetId = deploymentTargetId,
        environmentTypeName = environmentTypeName,
        identity = identity,
        location = location,
        projectName = projectName,
        resourceGroupName = resourceGroupName,
        status = status,
        tags = tags,
        userRoleAssignments = userRoleAssignments,
    )
}
